.. module:: enaml.stdlib.dialog_buttons

===========================
enaml.stdlib.dialog_buttons
===========================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    DialogButton
    DialogButtonBox


.. autoclass:: DialogButton

.. autoclass:: DialogButtonBox
